@@ -25,8 +25,6 @@ from oslo_config import fixture as fixture_config
 from oslotest import mockpatch
 import six
 from six.moves.urllib import parse as urlparse
-import sqlalchemy
-import testscenarios.testcase
 from testtools import testcase
 
 from aodh import service
@@ -51,22 +49,23 @@ class SQLManager(fixtures.Fixture):
     def __init__(self, conf):
         self.conf = conf
         db_name = 'aodh_%s' % uuid.uuid4().hex
-        self._engine = sqlalchemy.create_engine(
-            conf.database.connection.replace(self.url_dbname_placeholder,
-                                             self.url_dbname_createstring))
+        import sqlalchemy
+        self._engine = sqlalchemy.create_engine(conf.database.connection)
         self._conn = self._engine.connect()
         self._create_db(self._conn, db_name)
         self._conn.close()
         self._engine.dispose()
-        self.url = conf.database.connection.replace(
-            self.url_dbname_placeholder, db_name)
+        parsed = list(urlparse.urlparse(conf.database.connection))
+        # NOTE(jd) We need to set an host otherwise urlunparse() will not
+        # construct a proper URL
+        if parsed[1] == '':
+            parsed[1] = 'localhost'
+        parsed[2] = '/' + db_name
+        self.url = urlparse.urlunparse(parsed)
 
 
 class PgSQLManager(SQLManager):
 
-    url_dbname_placeholder = 'template1'
-    url_dbname_createstring = url_dbname_placeholder
-
     @staticmethod
     def _create_db(conn, db_name):
         conn.connection.set_isolation_level(0)
@@ -76,9 +75,6 @@ class PgSQLManager(SQLManager):
 
 class MySQLManager(SQLManager):
 
-    url_dbname_placeholder = 'test'
-    url_dbname_createstring = ''
-
     @staticmethod
     def _create_db(conn, db_name):
         conn.execute('CREATE DATABASE %s;' % db_name)
@@ -120,23 +116,29 @@ class SQLiteManager(fixtures.Fixture):
         self.url = "sqlite://"
 
 
-class TestBase(testscenarios.testcase.WithScenarios, test_base.BaseTestCase):
+@six.add_metaclass(test_base.SkipNotImplementedMeta)
+class TestBase(test_base.BaseTestCase):
 
     DRIVER_MANAGERS = {
         'mongodb': MongoDbManager,
         'mysql': MySQLManager,
-        'mysql+pymysql': MySQLManager,
         'postgresql': PgSQLManager,
         'sqlite': SQLiteManager,
     }
     if mocks is not None:
         DRIVER_MANAGERS['hbase'] = HBaseManager
 
-    db_url = 'sqlite://'  # NOTE(Alexei_987) Set default db url
-
     def setUp(self):
         super(TestBase, self).setUp()
-        engine = urlparse.urlparse(self.db_url).scheme
+        db_url = os.environ.get(
+            'AODH_TEST_STORAGE_URL',
+            os.environ.get(
+                "OVERTEST_URL", 'sqlite://').replace(
+                    "mysql://", "mysql+pymysql://"))
+        engine = urlparse.urlparse(db_url).scheme
+        # In case some drivers have additional specification, for example:
+        # PyMySQL will have scheme mysql+pymysql.
+        engine = engine.split('+')[0]
 
         # NOTE(Alexei_987) Shortcut to skip expensive db setUp
         test_method = self._get_test_method()
@@ -145,18 +147,21 @@ class TestBase(testscenarios.testcase.WithScenarios, test_base.BaseTestCase):
             raise testcase.TestSkipped(
                 'Test is not applicable for %s' % engine)
 
-        conf = service.prepare_service([])
+        conf = service.prepare_service(argv=[], config_files=[])
         self.CONF = self.useFixture(fixture_config.Config(conf)).conf
-        self.CONF.set_override('connection', self.db_url, group="database")
+        self.CONF.set_override('connection', db_url, group="database",
+                               enforce_type=True)
+
+        manager = self.DRIVER_MANAGERS.get(engine)
+        if not manager:
+            self.skipTest("missing driver manager: %s" % engine)
+
+        self.db_manager = manager(self.CONF)
 
-        try:
-            self.db_manager = self._get_driver_manager(engine)(self.CONF)
-        except ValueError as exc:
-            self.skipTest("missing driver manager: %s" % exc)
         self.useFixture(self.db_manager)
 
         self.CONF.set_override('connection', self.db_manager.url,
-                               group="database")
+                               group="database", enforce_type=True)
 
         self.alarm_conn = storage.get_connection_from_config(self.CONF)
         self.alarm_conn.upgrade()
@@ -173,12 +178,6 @@ class TestBase(testscenarios.testcase.WithScenarios, test_base.BaseTestCase):
     def _get_connection(self, conf):
         return self.alarm_conn
 
-    def _get_driver_manager(self, engine):
-        manager = self.DRIVER_MANAGERS.get(engine)
-        if not manager:
-            raise ValueError('No manager available for %s' % engine)
-        return manager
-
 
 def run_with(*drivers):
     """Used to mark tests that are only applicable for certain db driver.
@@ -200,24 +199,3 @@ def run_with(*drivers):
             test._run_with = drivers
         return test
     return decorator
-
-
-@six.add_metaclass(test_base.SkipNotImplementedMeta)
-class MixinTestsWithBackendScenarios(object):
-
-    scenarios = [
-        ('sqlite', {'db_url': 'sqlite://'}),
-    ]
-
-    for db in ('MONGODB', 'MYSQL', 'PGSQL', 'HBASE'):
-        if os.environ.get('AODH_TEST_%s_URL' % db):
-            scenarios.append(
-                (db.lower(), {'db_url': os.environ.get(
-                    'AODH_TEST_%s_URL' % db)}))
-
-    scenarios_db = [db for db, _ in scenarios]
-
-    # Insert default value for hbase test
-    if 'hbase' not in scenarios_db:
-        scenarios.append(
-            ('hbase', {'db_url': 'hbase://__test__'}))
