@@ -32,7 +32,7 @@ function aodh_service_url {
 }
 
 
-# _install_mongdb - Install mongodb and pyton lib.
+# _install_mongdb - Install mongodb and python lib.
 function _aodh_install_mongodb {
     # Server package is the same on all
     local packages=mongodb-server
@@ -84,12 +84,18 @@ function _aodh_config_apache_wsgi {
     fi
 
     sudo cp $AODH_DIR/devstack/apache-aodh.template $aodh_apache_conf
+    if [ "$AODH_BACKEND" = 'hbase' ] ; then
+        # Use one process to have single in-memory DB instance for data consistency
+        AODH_API_WORKERS=1
+    else
+        AODH_API_WORKERS=$API_WORKERS
+    fi
     sudo sed -e "
         s|%PORT%|$AODH_SERVICE_PORT|g;
         s|%APACHE_NAME%|$APACHE_NAME|g;
         s|%WSGIAPP%|$AODH_WSGI_DIR/app|g;
         s|%USER%|$STACK_USER|g;
-        s|%APIWORKERS%|$API_WORKERS|g;
+        s|%APIWORKERS%|$AODH_API_WORKERS|g;
         s|%VIRTUALENV%|$venv_path|g
     " -i $aodh_apache_conf
 }
@@ -117,15 +123,13 @@ function _aodh_create_accounts {
 
         create_service_user "aodh" "admin"
 
-        if [[ "$KEYSTONE_CATALOG_BACKEND" = 'sql' ]]; then
-            local aodh_service=$(get_or_create_service "aodh" \
-                "alarming" "OpenStack Alarming Service")
-            get_or_create_endpoint $aodh_service \
-                "$REGION_NAME" \
-                "$(aodh_service_url)/" \
-                "$(aodh_service_url)/" \
-                "$(aodh_service_url)/"
-        fi
+        local aodh_service=$(get_or_create_service "aodh" \
+            "alarming" "OpenStack Alarming Service")
+        get_or_create_endpoint $aodh_service \
+            "$REGION_NAME" \
+            "$(aodh_service_url)" \
+            "$(aodh_service_url)" \
+            "$(aodh_service_url)"
     fi
 }
 
@@ -160,10 +164,11 @@ function cleanup_aodh {
 function _aodh_configure_storage_backend {
     if [ "$AODH_BACKEND" = 'mysql' ] || [ "$AODH_BACKEND" = 'postgresql' ] ; then
         iniset $AODH_CONF database connection $(database_connection_url aodh)
-        iniset $AODH_CONF DEFAULT collector_workers $API_WORKERS
     elif [ "$AODH_BACKEND" = 'mongodb' ] ; then
         iniset $AODH_CONF database connection mongodb://localhost:27017/aodh
         cleanup_aodh
+    elif [ "$AODH_BACKEND" = 'hbase' ] ; then
+        iniset $AODH_CONF database connection hbase://__test__
     else
         die $LINENO "Unable to configure unknown AODH_BACKEND $AODH_BACKEND"
     fi
@@ -187,14 +192,17 @@ function configure_aodh {
 
     cp $AODH_DIR/etc/aodh/api_paste.ini $AODH_CONF_DIR
 
-    # The alarm evaluator needs these options to call aodh APIs
-    iniset $AODH_CONF service_credentials os_username aodh
-    iniset $AODH_CONF service_credentials os_password $SERVICE_PASSWORD
-    iniset $AODH_CONF service_credentials os_tenant_name $SERVICE_TENANT_NAME
-    iniset $AODH_CONF service_credentials os_region_name $REGION_NAME
-    iniset $AODH_CONF service_credentials os_auth_url $KEYSTONE_SERVICE_URI/v2.0
+    # The alarm evaluator needs these options to call gnocchi/ceilometer APIs
+    iniset $AODH_CONF service_credentials auth_type password
+    iniset $AODH_CONF service_credentials username aodh
+    iniset $AODH_CONF service_credentials user_domain_id default
+    iniset $AODH_CONF service_credentials project_domain_id default
+    iniset $AODH_CONF service_credentials password $SERVICE_PASSWORD
+    iniset $AODH_CONF service_credentials project_name $SERVICE_PROJECT_NAME
+    iniset $AODH_CONF service_credentials region_name $REGION_NAME
+    iniset $AODH_CONF service_credentials auth_url $KEYSTONE_SERVICE_URI
 
-    configure_auth_token_middleware $AODH_CONF aodh $AODH_AUTH_CACHE_DIR 
+    configure_auth_token_middleware $AODH_CONF aodh $AODH_AUTH_CACHE_DIR
 
     iniset $AODH_CONF notification store_events $AODH_EVENTS
 
@@ -207,6 +215,10 @@ function configure_aodh {
         iniset $AODH_CONF api pecan_debug "False"
         _aodh_config_apache_wsgi
     fi
+
+    if is_service_enabled gnocchi-api; then
+        iniset $AODH_CONF DEFAULT gnocchi_url $(gnocchi_service_url)
+    fi
 }
 
 # init_aodh() - Initialize etc.
@@ -234,7 +246,7 @@ function install_aodh {
     _aodh_prepare_coordination
     _aodh_prepare_storage_backend
     install_aodhclient
-    setup_develop $AODH_DIR
+    sudo -H pip install -e "$AODH_DIR"[test,$AODH_BACKEND]
     sudo install -d -o $STACK_USER -m 755 $AODH_CONF_DIR $AODH_API_LOG_DIR
 }
 
